@@ -61,7 +61,7 @@ class Forecast(Workflow, ModelSQL, ModelView):
     state = fields.Selection([
             ('draft', "Draft"),
             ('done', "Done"),
-            ('cancel', "Cancel"),
+            ('cancelled', "Cancelled"),
             ], "State", readonly=True, select=True)
     active = fields.Function(fields.Boolean('Active'),
         'get_active', searcher='search_active')
@@ -75,9 +75,9 @@ class Forecast(Workflow, ModelSQL, ModelView):
         cls._order.insert(1, ('warehouse', 'ASC'))
         cls._transitions |= set((
                 ('draft', 'done'),
-                ('draft', 'cancel'),
+                ('draft', 'cancelled'),
                 ('done', 'draft'),
-                ('cancel', 'draft'),
+                ('cancelled', 'draft'),
                 ))
         cls._buttons.update({
                 'cancel': {
@@ -101,6 +101,9 @@ class Forecast(Workflow, ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        cursor = Transaction().connection.cursor()
+        sql_table = cls.__table__()
+
         super(Forecast, cls).__register__(module_name)
 
         # Add index on create_date
@@ -110,6 +113,11 @@ class Forecast(Workflow, ModelSQL, ModelView):
         # Migration from 5.0: remove check_from_to_date
         table.drop_constraint('check_from_to_date')
 
+        # Migration from 5.6: rename state cancel to cancelled
+        cursor.execute(*sql_table.update(
+                [sql_table.state], ['cancelled'],
+                where=sql_table.state == 'cancel'))
+
     @staticmethod
     def default_state():
         return 'draft'
@@ -197,7 +205,7 @@ class Forecast(Workflow, ModelSQL, ModelView):
         # Cancel before delete
         cls.cancel(forecasts)
         for forecast in forecasts:
-            if forecast.state != 'cancel':
+            if forecast.state != 'cancelled':
                 raise AccessError(
                     gettext('stock_forecast.msg_forecast_delete_cancel',
                         forecast=forecast.rec_name))
@@ -217,7 +225,7 @@ class Forecast(Workflow, ModelSQL, ModelView):
 
     @classmethod
     @ModelView.button
-    @Workflow.transition('cancel')
+    @Workflow.transition('cancelled')
     def cancel(cls, forecasts):
         pass
 
@@ -403,7 +411,7 @@ class ForecastLine(ModelSQL, ModelView):
                         & (location_from.right <= forecast.warehouse.right)
                         & (location_to.left >= forecast.destination.left)
                         & (location_to.right <= forecast.destination.right)
-                        & (move.state != 'cancel')
+                        & (move.state != 'cancelled')
                         & (Coalesce(move.effective_date, move.planned_date)
                             >= forecast.from_date)
                         & (Coalesce(move.effective_date, move.planned_date)
@@ -555,25 +563,21 @@ class ForecastComplete(Wizard):
         """
         Forecast dates shifted by one year.
         """
-        Forecast = Pool().get('stock.forecast')
-        forecast = Forecast(Transaction().context['active_id'])
-
-        res = {}
+        default = {}
         for field in ("to_date", "from_date"):
-            res[field] = getattr(forecast, field) - relativedelta(years=1)
-        return res
+            default[field] = (
+                getattr(self.record, field) - relativedelta(years=1))
+        return default
 
     def _get_product_quantity(self):
         pool = Pool()
-        Forecast = pool.get('stock.forecast')
         Product = pool.get('product.product')
-        forecast = Forecast(Transaction().context['active_id'])
 
         with Transaction().set_context(
-                stock_destinations=[forecast.destination.id],
+                stock_destinations=[self.record.destination.id],
                 stock_date_start=self.ask.from_date,
                 stock_date_end=self.ask.to_date):
-            return Product.products_by_location([forecast.warehouse.id],
+            return Product.products_by_location([self.record.warehouse.id],
                 with_childs=True)
 
     def default_choose(self, fields):
@@ -592,11 +596,10 @@ class ForecastComplete(Wizard):
 
     def transition_complete(self):
         pool = Pool()
-        Forecast = pool.get('stock.forecast')
         ForecastLine = pool.get('stock.forecast.line')
         Product = pool.get('product.product')
 
-        forecast = Forecast(Transaction().context['active_id'])
+        forecast = self.record
         prod2line = {}
         forecast_lines = ForecastLine.search([
                 ('forecast', '=', forecast.id),
